@@ -1,8 +1,8 @@
 import sys
-import logging
-from typing import Generic, TypeVar
-from typing_extensions import Annotated
+from typing import Generic, TypeVar, Any
 
+from typing_extensions import Annotated
+from packaging import version
 from pydantic import Field
 from pydantic.fields import ModelField
 import numpy as np
@@ -10,11 +10,10 @@ import numpy as np
 Cuid = Annotated[str, Field(min_length=25, max_length=25)]
 
 DType = TypeVar('DType')
-
-logger = logging.getLogger(__name__)
+DShape = TypeVar('DShape')
 
 
-class TypedArray(np.ndarray, Generic[DType]):
+class _TypedArray(np.ndarray, Generic[DType, DShape]):
 
     @classmethod
     def __get_validators__(cls):
@@ -26,12 +25,19 @@ class TypedArray(np.ndarray, Generic[DType]):
             raise TypeError(f"Expected numpy array. Found {type(val)}")
 
         if sys.version_info.minor > 6:
-            actual_dtype = field.sub_fields[0].type_.__args__[0]
+            actual_dtype = field.sub_fields[-1].type_.__args__[0]
         else:
-            actual_dtype = field.sub_fields[0].type_.__values__[0]
+            actual_dtype = field.sub_fields[-1].type_.__values__[0]
 
         if val.dtype != actual_dtype:
             raise TypeError(
                 f"Expected numpy array have type {actual_dtype}. Found {val.dtype}"
             )
         return val
+
+
+if version.parse(np.__version__) >= version.parse('1.22.0'):
+    from numpy.typing import _GenericAlias
+    TypedArray = _GenericAlias(_TypedArray, (Any, DType))
+else:
+    TypedArray = _TypedArray[Any, DType]
